@@ -119,7 +119,7 @@ impl<K: PageNo, const NBYTES: usize> Pages<K, NBYTES> {
         })
     }
 
-    pub async fn write(&self, num: K, buf: [u8; NBYTES]) -> Result<usize> {
+    pub async fn write(&self, num: K, buf: [u8; NBYTES]) -> Result<()> {
         debug_assert!(num.as_u32() < self.len());
 
         let num = num.as_u32() as u64;
@@ -145,7 +145,7 @@ impl<K: PageNo, const NBYTES: usize> Pages<K, NBYTES> {
         }
     }
 
-    pub async fn create(&self, buf: [u8; NBYTES]) -> Result<usize> {
+    pub async fn create(&self, buf: [u8; NBYTES]) -> Result<()> {
         let num = self.len.fetch_add(1, Ordering::SeqCst);
         self.write(PageNo::new(num), buf).await
     }
