@@ -1,7 +1,7 @@
 use std::convert::TryInto;
 use std::hash::Hash;
 
-pub trait PageNo: Eq + Hash + Copy + Unpin + Send + Sync {
+pub trait PageNo: Eq + Hash + Copy + Unpin + Send + Sync + Ord + Default {
     /// Total number of bytes.
     const SIZE: usize;
     fn new(_: u32) -> Self;
@@ -28,7 +28,7 @@ macro_rules! impl_trait {
 impl_trait!(PageNo for u8:1 u16:2 u32:4);
 
 #[repr(transparent)]
-#[derive(Hash, PartialEq, Eq, Clone, Copy, Debug)]
+#[derive(Hash, PartialEq, Eq, Clone, Copy, Debug, PartialOrd, Ord, Default)]
 pub struct U24(u32);
 
 impl PageNo for U24 {
